Continued:
[core.git] / index.php
index 3cca6d52f2f0ac6a4f0dac63d963a25bf24d2e23..e3c5da87df742caed7a31be487ec3306d16460a3 100644 (file)
--- a/index.php
+++ b/index.php
@@ -1,15 +1,15 @@
 <?php
 // Own namespace (watch out: core)
-namespace CoreFramework\EntryPoint;
+namespace Org\Mxchange\CoreFramework\EntryPoint;
 
 // Import framework stuff
-use CoreFramework\Bootstrap\FrameworkBootstrap;
-use CoreFramework\Configuration\FrameworkConfiguration;
-use CoreFramework\Factory\ObjectFactory;
-use CoreFramework\Helper\Application\ApplicationHelper;
-use CoreFramework\Localization\LanguageSystem;
-use CoreFramework\Loader\ClassLoader;
-use CoreFramework\Generic\FrameworkException;
+use Org\Mxchange\CoreFramework\Bootstrap\FrameworkBootstrap;
+use Org\Mxchange\CoreFramework\Factory\ObjectFactory;
+use Org\Mxchange\CoreFramework\Filesystem\FileNotFoundException;
+use Org\Mxchange\CoreFramework\Helper\Application\ApplicationHelper;
+use Org\Mxchange\CoreFramework\Localization\LanguageSystem;
+use Org\Mxchange\CoreFramework\Loader\ClassLoader;
+use Org\Mxchange\CoreFramework\Generic\FrameworkException;
 
 // Import SPL stuff
 use \Exception;
@@ -24,7 +24,7 @@ use \Exception;
  *
  * @author             Roland Haeder <webmaster@shipsimu.org>
  * @version            0.0.0
- * @copyright  Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Core Developer Team
+ * @copyright  Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
  * @license            GNU GPL 3.0 or any newer version
  * @link               http://www.shipsimu.org
  *
@@ -57,7 +57,7 @@ final class ApplicationEntryPoint {
         * @return      void
         * @todo        This method is old code and needs heavy rewrite and should be moved to ApplicationHelper
         */
-       public static final function app_exit ($message = '', $code = FALSE, $extraData = '', $silentMode = FALSE) {
+       public static final function exitApplication ($message = '', $code = false, $extraData = '', $silentMode = false) {
                // Is this method already called?
                if (isset($GLOBALS['app_die_called'])) {
                        // Then output the text directly
@@ -65,7 +65,7 @@ final class ApplicationEntryPoint {
                } // END - if
 
                // This method shall not be called twice
-               $GLOBALS['app_die_called'] = TRUE;
+               $GLOBALS['app_die_called'] = true;
 
                // Is a message set?
                if (empty($message)) {
@@ -74,10 +74,10 @@ final class ApplicationEntryPoint {
                } // END - if
 
                // Get config instance
-               $configInstance = FrameworkConfiguration::getSelfInstance();
+               $configInstance = FrameworkBootstrap::getConfigurationInstance();
 
                // Do we have debug installation?
-               if (($configInstance->getConfigEntry('product_install_mode') == 'productive') || ($silentMode === TRUE)) {
+               if (($configInstance->getConfigEntry('product_install_mode') == 'productive') || ($silentMode === true)) {
                        // Abort here
                        exit();
                } // END - if
@@ -90,7 +90,7 @@ final class ApplicationEntryPoint {
                $templateInstance = NULL;
 
                // Get response instance
-               $responseInstance = ApplicationHelper::getSelfInstance()->getResponseInstance();
+               $responseInstance = FrameworkBootstrap::getResponseInstance();
 
                // Is the template engine loaded?
                if ((class_exists($tpl)) && (is_object($languageInstance))) {
@@ -132,12 +132,12 @@ final class ApplicationEntryPoint {
                        $applicationInstance = NULL;
 
                        // Is the class there?
-                       if (class_exists('CoreFramework\Helper\Application\ApplicationHelper')) {
+                       if (class_exists('Org\Mxchange\CoreFramework\Helper\Application\ApplicationHelper')) {
                                // Get application instance
                                $applicationInstance = ApplicationHelper::getSelfInstance();
 
                                // Assign application data
-                               $templateInstance->assignApplicationData($applicationInstance);
+                               $templateInstance->assignApplicationData();
                        } // END - if
 
                        // We only try this
@@ -192,35 +192,32 @@ final class ApplicationEntryPoint {
                // Is it not set?
                if (empty(self::$frameworkPath)) {
                        // Auto-detect core path (first application-common)
-                       foreach (array('core', '.', '/usr/local/share/php/core', '/usr/share/php/core') as $possiblePath) {
+                       foreach (array('core', __DIR__, '/usr/local/share/php/core', '/usr/share/php/core') as $possiblePath) {
                                // Create full path for testing
                                $realPath = realpath($possiblePath);
 
                                // Debug message
                                //* NOISY-DEBUG: */ printf('[%s:%d]: realPath[%s]=%s' . PHP_EOL, __METHOD__, __LINE__, gettype($realPath), $realPath);
 
-                               // Is it FALSE?
-                               if ($realPath === FALSE) {
+                               // Is it false?
+                               if ($realPath === false) {
                                        // Then, not found.
                                        continue;
                                } // END - if
 
-                               // First create full-qualified file name (FQFN) to framework/config.inc.php
-                               $fqfn = sprintf(
-                                       '%s%sframework%sconfig.inc.php',
-                                       $realPath,
-                                       DIRECTORY_SEPARATOR,
-                                       DIRECTORY_SEPARATOR,
-                                       $possiblePath
-                               );
+                               // Append framework path
+                               $frameworkPath = sprintf('%s%sframework%s', $realPath, DIRECTORY_SEPARATOR, DIRECTORY_SEPARATOR);
+
+                               // First create full-qualified file name (FQFN) to framework/config-global.php
+                               $configFile = $frameworkPath . 'config-global.php';
 
                                // Debug message
-                               //* NOISY-DEBUG: */ printf('[%s:%d]: fqfn=%s' . PHP_EOL, __METHOD__, __LINE__, $fqfn);
+                               //* NOISY-DEBUG: */ printf('[%s:%d]: configFile=%s' . PHP_EOL, __METHOD__, __LINE__, $configFile);
 
                                // Is it readable?
-                               if (is_readable($fqfn)) {
+                               if (is_readable($configFile)) {
                                        // Found one
-                                       self::$frameworkPath = $realPath . '/framework/';
+                                       self::$frameworkPath = $frameworkPath;
 
                                        // Abort here
                                        break;
@@ -258,21 +255,30 @@ final class ApplicationEntryPoint {
         */
        public static final function main () {
                // Load bootstrap file
-               require self::detectFrameworkPath() . 'bootstrap/bootstrap.inc.php';
+               require sprintf('%sbootstrap%sbootstrap.inc.php', self::detectFrameworkPath(), DIRECTORY_SEPARATOR);
+
+               /*
+                * Initial bootstrap is done, continue with initialization of
+                * framework.
+                */
+               FrameworkBootstrap::initFramework();
+
+               // Next initialize the detected application
+               FrameworkBootstrap::prepareApplication();
 
                /*
-                * Initial bootstrap is done, continue with parsing parameters and
-                * look for 'app'.
+                * Last step is to start the application, this will also initialize and
+                * register the application instance in registry.
                 */
-               FrameworkBootstrap::parseParameters();
+               FrameworkBootstrap::startApplication();
        }
 }
 
 // Developer mode active? Comment out if no dev!
-define('DEVELOPER', TRUE);
+define('DEVELOPER', true);
 
 // Log all exceptions (only debug! This option can create large error logs)
-//define('LOG_EXCEPTIONS', TRUE);
+//define('LOG_EXCEPTIONS', true);
 
 //xdebug_start_trace();